@@ -316,7 +316,7 @@ class FilesystemHandler(pyarrow.fs.FileSystemHandler):
             file_system_name,
             credential=credential
         )
-        return cls(client, timeouts)
+        return cls(client, timeouts=timeouts)
 
     def __eq__(self, other):
         if isinstance(other, FilesystemHandler):
@@ -367,7 +367,7 @@ class FilesystemHandler(pyarrow.fs.FileSystemHandler):
                         raise NotADirectoryError(self._prefix(path))
                     return
             raise NotADirectoryError(self._prefix(path))
-        except azure.storage.filedatalake._models.StorageErrorException as e:
+        except azure.core.exceptions.HttpResponseError as e:
             if e.status_code == 404:
                 raise FileNotFoundError(self._prefix(path))
             else:
